==> sparkautomapper.fhir-0.2.21b1-py3-none-any.whl: spark_auto_mapper_fhir/backbone_elements/claim_item.py <==
from __future__ import annotations
from typing import Optional, TYPE_CHECKING, Union

from spark_auto_mapper_fhir.fhir_types.date import FhirDate
from spark_auto_mapper_fhir.fhir_types.list import FhirList
from spark_auto_mapper_fhir.extensions.extension_base import ExtensionBase
from spark_auto_mapper_fhir.fhir_types.id import FhirId

from spark_auto_mapper_fhir.base_types.fhir_backbone_element_base import (
    FhirBackboneElementBase,
)

if TYPE_CHECKING:
    pass
    # sequence (positiveInt)
    from spark_auto_mapper_fhir.complex_types.positive_int import positiveInt

    # careTeamSequence (positiveInt)
    # diagnosisSequence (positiveInt)
    # procedureSequence (positiveInt)
    # informationSequence (positiveInt)
    # revenue (CodeableConcept)
    from spark_auto_mapper_fhir.complex_types.codeable_concept import CodeableConcept

    # End Import for References for revenue
    # Import for CodeableConcept for revenue
    from spark_auto_mapper_fhir.value_sets.example_revenue_center_codes import (
        ExampleRevenueCenterCodesCode,
    )

    # End Import for CodeableConcept for revenue
    # category (CodeableConcept)
    # End Import for References for category
    # Import for CodeableConcept for category
    from spark_auto_mapper_fhir.value_sets.benefit_category_codes import (
        BenefitCategoryCodesCode,
    )

    # End Import for CodeableConcept for category
    # productOrService (CodeableConcept)
    # End Import for References for productOrService
    # Import for CodeableConcept for productOrService
    from spark_auto_mapper_fhir.value_sets.uscls_codes import USCLSCodesCode

    # End Import for CodeableConcept for productOrService
    # modifier (CodeableConcept)
    # End Import for References for modifier
    # Import for CodeableConcept for modifier
    from spark_auto_mapper_fhir.value_sets.modifier_type_codes import (
        ModifierTypeCodesCode,
    )

    # End Import for CodeableConcept for modifier
    # programCode (CodeableConcept)
    # End Import for References for programCode
    # Import for CodeableConcept for programCode
    from spark_auto_mapper_fhir.value_sets.example_program_reason_codes import (
        ExampleProgramReasonCodesCode,
    )

    # End Import for CodeableConcept for programCode
    # quantity (Quantity)
    from spark_auto_mapper_fhir.complex_types.quantity import Quantity

    # unitPrice (Money)
    from spark_auto_mapper_fhir.complex_types.money import Money

    # factor (decimal)
    from spark_auto_mapper_fhir.complex_types.decimal import decimal

    # net (Money)
    # udi (Reference)
    from spark_auto_mapper_fhir.complex_types.reference import Reference

    # Imports for References for udi
    from spark_auto_mapper_fhir.resources.device import Device

    # bodySite (CodeableConcept)
    # End Import for References for bodySite
    # Import for CodeableConcept for bodySite
    from spark_auto_mapper_fhir.value_sets.oral_site_codes import OralSiteCodesCode

    # End Import for CodeableConcept for bodySite
    # subSite (CodeableConcept)
    # End Import for References for subSite
    # Import for CodeableConcept for subSite
    from spark_auto_mapper_fhir.value_sets.surface_codes import SurfaceCodesCode

    # End Import for CodeableConcept for subSite
    # encounter (Reference)
    # Imports for References for encounter
    from spark_auto_mapper_fhir.resources.encounter import Encounter

    # detail (Claim.Detail)
    from spark_auto_mapper_fhir.backbone_elements.claim_detail import ClaimDetail

    # servicedDate (date)
    # servicedPeriod (Period)
    from spark_auto_mapper_fhir.complex_types.period import Period

    # locationCodeableConcept (CodeableConcept)
    # End Import for References for locationCodeableConcept
    # Import for CodeableConcept for locationCodeableConcept
    from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode

    # End Import for CodeableConcept for locationCodeableConcept
    # locationAddress (Address)
    from spark_auto_mapper_fhir.complex_types.address import Address

    # locationReference (Reference)
    # Imports for References for locationReference
    from spark_auto_mapper_fhir.resources.location import Location


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class ClaimItem(FhirBackboneElementBase):
    """
    Claim.Item
    """

    # noinspection PyPep8Naming
    def __init__(
        self,
        *,
        id_: Optional[FhirId] = None,
        extension: Optional[FhirList[ExtensionBase]] = None,
        sequence: positiveInt,
        careTeamSequence: Optional[FhirList[positiveInt]] = None,
        diagnosisSequence: Optional[FhirList[positiveInt]] = None,
        procedureSequence: Optional[FhirList[positiveInt]] = None,
        informationSequence: Optional[FhirList[positiveInt]] = None,
        revenue: Optional[CodeableConcept[ExampleRevenueCenterCodesCode]] = None,
        category: Optional[CodeableConcept[BenefitCategoryCodesCode]] = None,
        productOrService: CodeableConcept[USCLSCodesCode],
        modifier: Optional[FhirList[CodeableConcept[ModifierTypeCodesCode]]] = None,
        programCode: Optional[
            FhirList[CodeableConcept[ExampleProgramReasonCodesCode]]
        ] = None,
        quantity: Optional[Quantity] = None,
        unitPrice: Optional[Money] = None,
        factor: Optional[decimal] = None,
        net: Optional[Money] = None,
        udi: Optional[FhirList[Reference[Union[Device]]]] = None,
        bodySite: Optional[CodeableConcept[OralSiteCodesCode]] = None,
        subSite: Optional[FhirList[CodeableConcept[SurfaceCodesCode]]] = None,
        encounter: Optional[FhirList[Reference[Union[Encounter]]]] = None,
        detail: Optional[FhirList[ClaimDetail]] = None,
        servicedDate: Optional[FhirDate] = None,
        servicedPeriod: Optional[Period] = None,
        locationCodeableConcept: Optional[CodeableConcept[GenericTypeCode]] = None,
        locationAddress: Optional[Address] = None,
        locationReference: Optional[Reference[Union[Location]]] = None,
    ) -> None:
        """

            :param id_: id of resource
            :param extension: extensions
            :param sequence: A number to uniquely identify item entries.
            :param careTeamSequence: CareTeam members related to this service or product.
            :param diagnosisSequence: Diagnosis applicable for this service or product.
            :param procedureSequence: Procedures applicable for this service or product.
            :param informationSequence: Exceptions, special conditions and supporting information applicable for this
        service or product.
            :param revenue: The type of revenue or cost center providing the product and/or service.
            :param category: Code to identify the general type of benefits under which products and
        services are provided.
            :param productOrService: When the value is a group code then this item collects a set of related claim
        details, otherwise this contains the product, service, drug or other billing
        code for the item.
            :param modifier: Item typification or modifiers codes to convey additional context for the
        product or service.
            :param programCode: Identifies the program under which this may be recovered.
            :param quantity: The number of repetitions of a service or product.
            :param unitPrice: If the item is not a group then this is the fee for the product or service,
        otherwise this is the total of the fees for the details of the group.
            :param factor: A real number that represents a multiplier used in determining the overall
        value of services delivered and/or goods received. The concept of a Factor
        allows for a discount or surcharge multiplier to be applied to a monetary
        amount.
            :param net: The quantity times the unit price for an additional service or product or
        charge.
            :param udi: Unique Device Identifiers associated with this line item.
            :param bodySite: Physical service site on the patient (limb, tooth, etc.).
            :param subSite: A region or surface of the bodySite, e.g. limb region or tooth surface(s).
            :param encounter: The Encounters during which this Claim was created or to which the creation of
        this record is tightly associated.
            :param detail: A claim detail line. Either a simple (a product or service) or a 'group' of
        sub-details which are simple items.
            :param servicedDate: None
            :param servicedPeriod: None
            :param locationCodeableConcept: None
            :param locationAddress: None
            :param locationReference: None
        """
        super().__init__(
            id_=id_,
            extension=extension,
            sequence=sequence,
            careTeamSequence=careTeamSequence,
            diagnosisSequence=diagnosisSequence,
            procedureSequence=procedureSequence,
            informationSequence=informationSequence,
            revenue=revenue,
            category=category,
            productOrService=productOrService,
            modifier=modifier,
            programCode=programCode,
            quantity=quantity,
            unitPrice=unitPrice,
            factor=factor,
            net=net,
            udi=udi,
            bodySite=bodySite,
            subSite=subSite,
            encounter=encounter,
            detail=detail,
            servicedDate=servicedDate,
            servicedPeriod=servicedPeriod,
            locationCodeableConcept=locationCodeableConcept,
            locationAddress=locationAddress,
            locationReference=locationReference,
        )

==> sparkautomapper.fhir-1.0.10-py3-none-any.whl: spark_auto_mapper_fhir/backbone_elements/claim_item.py <==
from __future__ import annotations
from typing import Optional, TYPE_CHECKING

from spark_auto_mapper_fhir.fhir_types.date import FhirDate
from spark_auto_mapper_fhir.fhir_types.list import FhirList
from spark_auto_mapper_fhir.fhir_types.string import FhirString
from spark_auto_mapper_fhir.extensions.extension_base import ExtensionBase

from spark_auto_mapper_fhir.base_types.fhir_backbone_element_base import (
    FhirBackboneElementBase,
)

if TYPE_CHECKING:
    pass
    # id_ (string)
    # extension (Extension)
    # modifierExtension (Extension)
    # sequence (positiveInt)
    from spark_auto_mapper_fhir.fhir_types.positive_int import FhirPositiveInt

    # careTeamSequence (positiveInt)
    # diagnosisSequence (positiveInt)
    # procedureSequence (positiveInt)
    # informationSequence (positiveInt)
    # revenue (CodeableConcept)
    from spark_auto_mapper_fhir.complex_types.codeable_concept import CodeableConcept

    # End Import for References for revenue
    # Import for CodeableConcept for revenue
    from spark_auto_mapper_fhir.value_sets.example_revenue_center_codes import (
        ExampleRevenueCenterCodesCode,
    )

    # End Import for CodeableConcept for revenue
    # category (CodeableConcept)
    # End Import for References for category
    # Import for CodeableConcept for category
    from spark_auto_mapper_fhir.value_sets.benefit_category_codes import (
        BenefitCategoryCodesCode,
    )

    # End Import for CodeableConcept for category
    # productOrService (CodeableConcept)
    # End Import for References for productOrService
    # Import for CodeableConcept for productOrService
    from spark_auto_mapper_fhir.value_sets.uscls_codes import USCLSCodesCode

    # End Import for CodeableConcept for productOrService
    # modifier (CodeableConcept)
    # End Import for References for modifier
    # Import for CodeableConcept for modifier
    from spark_auto_mapper_fhir.value_sets.modifier_type_codes import (
        ModifierTypeCodesCode,
    )

    # End Import for CodeableConcept for modifier
    # programCode (CodeableConcept)
    # End Import for References for programCode
    # Import for CodeableConcept for programCode
    from spark_auto_mapper_fhir.value_sets.example_program_reason_codes import (
        ExampleProgramReasonCodesCode,
    )

    # End Import for CodeableConcept for programCode
    # servicedDate (date)
    # servicedPeriod (Period)
    from spark_auto_mapper_fhir.complex_types.period import Period

    # locationCodeableConcept (CodeableConcept)
    # End Import for References for locationCodeableConcept
    # Import for CodeableConcept for locationCodeableConcept
    from spark_auto_mapper_fhir.value_sets.example_service_place_codes import (
        ExampleServicePlaceCodesCode,
    )

    # End Import for CodeableConcept for locationCodeableConcept
    # locationAddress (Address)
    from spark_auto_mapper_fhir.complex_types.address import Address

    # locationReference (Reference)
    from spark_auto_mapper_fhir.complex_types.reference import Reference

    # Imports for References for locationReference
    from spark_auto_mapper_fhir.resources.location import Location

    # quantity (Quantity)
    from spark_auto_mapper_fhir.complex_types.quantity import Quantity

    # unitPrice (Money)
    from spark_auto_mapper_fhir.complex_types.money import Money

    # factor (decimal)
    from spark_auto_mapper_fhir.fhir_types.decimal import FhirDecimal

    # net (Money)
    # udi (Reference)
    # Imports for References for udi
    from spark_auto_mapper_fhir.resources.device import Device

    # bodySite (CodeableConcept)
    # End Import for References for bodySite
    # Import for CodeableConcept for bodySite
    from spark_auto_mapper_fhir.value_sets.oral_site_codes import OralSiteCodesCode

    # End Import for CodeableConcept for bodySite
    # subSite (CodeableConcept)
    # End Import for References for subSite
    # Import for CodeableConcept for subSite
    from spark_auto_mapper_fhir.value_sets.surface_codes import SurfaceCodesCode

    # End Import for CodeableConcept for subSite
    # encounter (Reference)
    # Imports for References for encounter
    from spark_auto_mapper_fhir.resources.encounter import Encounter

    # detail (Claim.Detail)
    from spark_auto_mapper_fhir.backbone_elements.claim_detail import ClaimDetail


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class ClaimItem(FhirBackboneElementBase):
    """
    Claim.Item
        A provider issued list of professional services and products which have been provided, or are to be provided, to a patient which is sent to an insurer for reimbursement.
    """

    # noinspection PyPep8Naming
    def __init__(
        self,
        *,
        id_: Optional[FhirString] = None,
        extension: Optional[FhirList[ExtensionBase]] = None,
        modifierExtension: Optional[FhirList[ExtensionBase]] = None,
        sequence: FhirPositiveInt,
        careTeamSequence: Optional[FhirList[FhirPositiveInt]] = None,
        diagnosisSequence: Optional[FhirList[FhirPositiveInt]] = None,
        procedureSequence: Optional[FhirList[FhirPositiveInt]] = None,
        informationSequence: Optional[FhirList[FhirPositiveInt]] = None,
        revenue: Optional[CodeableConcept[ExampleRevenueCenterCodesCode]] = None,
        category: Optional[CodeableConcept[BenefitCategoryCodesCode]] = None,
        productOrService: CodeableConcept[USCLSCodesCode],
        modifier: Optional[FhirList[CodeableConcept[ModifierTypeCodesCode]]] = None,
        programCode: Optional[
            FhirList[CodeableConcept[ExampleProgramReasonCodesCode]]
        ] = None,
        servicedDate: Optional[FhirDate] = None,
        servicedPeriod: Optional[Period] = None,
        locationCodeableConcept: Optional[
            CodeableConcept[ExampleServicePlaceCodesCode]
        ] = None,
        locationAddress: Optional[Address] = None,
        locationReference: Optional[Reference[Location]] = None,
        quantity: Optional[Quantity] = None,
        unitPrice: Optional[Money] = None,
        factor: Optional[FhirDecimal] = None,
        net: Optional[Money] = None,
        udi: Optional[FhirList[Reference[Device]]] = None,
        bodySite: Optional[CodeableConcept[OralSiteCodesCode]] = None,
        subSite: Optional[FhirList[CodeableConcept[SurfaceCodesCode]]] = None,
        encounter: Optional[FhirList[Reference[Encounter]]] = None,
        detail: Optional[FhirList[ClaimDetail]] = None,
    ) -> None:
        """
            A provider issued list of professional services and products which have been
        provided, or are to be provided, to a patient which is sent to an insurer for
        reimbursement.

            :param id_: None
            :param extension: May be used to represent additional information that is not part of the basic
        definition of the element. To make the use of extensions safe and manageable,
        there is a strict set of governance  applied to the definition and use of
        extensions. Though any implementer can define an extension, there is a set of
        requirements that SHALL be met as part of the definition of the extension.
            :param modifierExtension: May be used to represent additional information that is not part of the basic
        definition of the element and that modifies the understanding of the element
        in which it is contained and/or the understanding of the containing element's
        descendants. Usually modifier elements provide negation or qualification. To
        make the use of extensions safe and manageable, there is a strict set of
        governance applied to the definition and use of extensions. Though any
        implementer can define an extension, there is a set of requirements that SHALL
        be met as part of the definition of the extension. Applications processing a
        resource are required to check for modifier extensions.

        Modifier extensions SHALL NOT change the meaning of any elements on Resource
        or DomainResource (including cannot change the meaning of modifierExtension
        itself).
            :param sequence: A number to uniquely identify item entries.
            :param careTeamSequence: CareTeam members related to this service or product.
            :param diagnosisSequence: Diagnosis applicable for this service or product.
            :param procedureSequence: Procedures applicable for this service or product.
            :param informationSequence: Exceptions, special conditions and supporting information applicable for this
        service or product.
            :param revenue: The type of revenue or cost center providing the product and/or service.
            :param category: Code to identify the general type of benefits under which products and
        services are provided.
            :param productOrService: When the value is a group code then this item collects a set of related claim
        details, otherwise this contains the product, service, drug or other billing
        code for the item.
            :param modifier: Item typification or modifiers codes to convey additional context for the
        product or service.
            :param programCode: Identifies the program under which this may be recovered.
            :param servicedDate: None
            :param servicedPeriod: None
            :param locationCodeableConcept: None
            :param locationAddress: None
            :param locationReference: None
            :param quantity: The number of repetitions of a service or product.
            :param unitPrice: If the item is not a group then this is the fee for the product or service,
        otherwise this is the total of the fees for the details of the group.
            :param factor: A real number that represents a multiplier used in determining the overall
        value of services delivered and/or goods received. The concept of a Factor
        allows for a discount or surcharge multiplier to be applied to a monetary
        amount.
            :param net: The quantity times the unit price for an additional service or product or
        charge.
            :param udi: Unique Device Identifiers associated with this line item.
            :param bodySite: Physical service site on the patient (limb, tooth, etc.).
            :param subSite: A region or surface of the bodySite, e.g. limb region or tooth surface(s).
            :param encounter: The Encounters during which this Claim was created or to which the creation of
        this record is tightly associated.
            :param detail: A claim detail line. Either a simple (a product or service) or a 'group' of
        sub-details which are simple items.
        """
        super().__init__(
            id_=id_,
            extension=extension,
            modifierExtension=modifierExtension,
            sequence=sequence,
            careTeamSequence=careTeamSequence,
            diagnosisSequence=diagnosisSequence,
            procedureSequence=procedureSequence,
            informationSequence=informationSequence,
            revenue=revenue,
            category=category,
            productOrService=productOrService,
            modifier=modifier,
            programCode=programCode,
            servicedDate=servicedDate,
            servicedPeriod=servicedPeriod,
            locationCodeableConcept=locationCodeableConcept,
            locationAddress=locationAddress,
            locationReference=locationReference,
            quantity=quantity,
            unitPrice=unitPrice,
            factor=factor,
            net=net,
            udi=udi,
            bodySite=bodySite,
            subSite=subSite,
            encounter=encounter,
            detail=detail,
        )
